@@ -333,24 +333,26 @@ def getgmap(band, ufwhm, uellip, searchrad, minsep, urms, lstarnum):
                 fin = open('match.txt')
                 for line in fin:
                     if not line.startswith('#') and re.search('\S',line[:-1]):
-                        mnum += 1
+                        if not line.startswith('        0.000         0.000          0.000         0.000'):
+                            mnum += 1
                 fin.close()
 
-                while mnum < 0.5 * min(refnum, innum) and nmatch < 61:
+                if mnum > 10:
+                    while mnum < 0.5 * min(refnum, innum) and nmatch < 61:
 
-                    nmatch += 5
+                        nmatch += 5
 
-                    # print 'xyxymatch again with nmatch=%d for %s' % (nmatch, v[0])
-                    if os.access('match.txt', os.R_OK):
-                        os.remove('match.txt')
-                    iraf.xyxymatch(timgin, timgref, 'match.txt', 1, nmatch=nmatch, verbose='no')
+                        # print 'xyxymatch again with nmatch=%d for %s' % (nmatch, v[0])
+                        if os.access('match.txt', os.R_OK):
+                            os.remove('match.txt')
+                        iraf.xyxymatch(timgin, timgref, 'match.txt', 1, nmatch=nmatch, verbose='no')
 
-                    mnum = 0
-                    fin = open('match.txt')
-                    for line in fin:
-                        if not line.startswith('#') and re.search('\S',line[:-1]):
-                            mnum += 1
-                    fin.close()
+                        mnum = 0
+                        fin = open('match.txt')
+                        for line in fin:
+                            if not line.startswith('#') and re.search('\S',line[:-1]):
+                                mnum += 1
+                        fin.close()
 
             else:
                 print 'no common stars in the overlapped area of %s and %s' % (imgref[:-4], v[0])
