@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 
+# 2014-02-18 tuneparam :  'while num > 500' changed to 'while num > 250'
+
 import os
 import sys
 import re
@@ -48,9 +50,9 @@ def tuneparam(ffile, fnum, mlim):
            num += 1 
     f.close()
 
-    while num > 500:    #  2013.5.1
+    while num > 250:    #  2014-02-18
         os.remove('ap.coo')
-        iraf.apphot.findpars.threshold = 2 * iraf.apphot.findpars.threshold
+        iraf.apphot.findpars.threshold += 5
         iraf.daofind('recomtmp.fits')
         num = 0
         f = open('ap.coo')
